=========
Changelog
=========

Version 0.0.0
=============

A synchronous client (AttoClient) with most of the GET methods implemented.

* Minimal documentation
* No testing framework
* No POST methods
* No GET methods that don't work with https://gatekeeper.live.application.atto.cash/
